@@ -1,8 +1,23 @@
 import {ExtentTransformNode} from '../../../src/compile/data/extent';
 import {Transform} from '../../../src/transform';
 import {PlaceholderDataFlowNode} from './util';
+import {isExtent} from '../../../src/transform';
 
 describe('compile/data/extent', () => {
+  describe('isExtent', () => {
+    it('should return true for a regular extent transform', () => {
+      expect(isExtent({extent: 'a', param: 'A'})).toBe(true);
+    });
+
+    it('should return false for a regression transform', () => {
+      expect(isExtent({regression: 'a', on: 'b', extent: [0, 10]})).toBe(false);
+    });
+
+    it('should return false for a density transform', () => {
+      expect(isExtent({density: 'a', extent: [0, 10]})).toBe(false);
+    });
+  });
+
   describe('assemble', () => {
     it('should return a proper vg transform', () => {
       const transform: Transform = {
